@@ -1,2 +1,2 @@
-from .update import UpdateDownloader
+from .update import CentralizedUpdateDownloader
 from .file import FileFeeder, DirFeeder, WalkFeeder, ExtFilterFeeder
